package com.zhyc.module.biosafety.mapper;

import java.util.List;

import com.zhyc.module.biosafety.domain.QuarantineSample;
import org.apache.ibatis.annotations.Mapper;

/**
 * 样品类型Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-14
 */
@Mapper
public interface QuarantineSampleMapper 
{
    /**
     * 查询样品类型
     * 
     * @param id 样品类型主键
     * @return 样品类型
     */
    public QuarantineSample selectQuarantineSampleById(Long id);

    /**
     * 查询样品类型列表
     * 
     * @param quarantineSample 样品类型
     * @return 样品类型集合
     */
    public List<QuarantineSample> selectQuarantineSampleList(QuarantineSample quarantineSample);

    /**
     * 新增样品类型
     * 
     * @param quarantineSample 样品类型
     * @return 结果
     */
    public int insertQuarantineSample(QuarantineSample quarantineSample);

    /**
     * 修改样品类型
     * 
     * @param quarantineSample 样品类型
     * @return 结果
     */
    public int updateQuarantineSample(QuarantineSample quarantineSample);

    /**
     * 删除样品类型
     * 
     * @param id 样品类型主键
     * @return 结果
     */
    public int deleteQuarantineSampleById(Long id);

    /**
     * 批量删除样品类型
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQuarantineSampleByIds(Long[] ids);
}
